sudo cp -r pyttrading /Users/ceciliocannavaciuolo/miniconda3/envs/python3.12/lib/python3.12/site-packages

sudo cp -r pyttrading /opt/homebrew/Caskroom/miniconda/base/envs/python3.12/lib/python3.12/site-packages